<?php

declare(strict_types=1);

/*
 * Copyright (C) 2023 Daniel Siepmann <coding@daniel-siepmann.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

namespace DanielSiepmann\FediverseFeedWrappers\Tests\Unit\Wrapper;

use DanielSiepmann\FediverseFeedWrappers\WrapperInterface;
use DanielSiepmann\FediverseFeedWrappers\Wrapper\Frontpage;
use PHPUnit\Framework\TestCase;

/**
 * @covers \DanielSiepmann\FediverseFeedWrappers\Wrapper\Frontpage
 */
class FrontpageTest extends TestCase
{
    /**
     * @test
     */
    public function canBeCreated(): void
    {
        $subject = new Frontpage();

        self::assertInstanceOf(
            Frontpage::class,
            $subject
        );
    }

    /**
     * @test
     */
    public function isInstanceOfWrapperInterface(): void
    {
        $subject = new Frontpage();

        self::assertInstanceOf(
            WrapperInterface::class,
            $subject
        );
    }

    /**
     * @test
     */
    public function returnsContentType(): void
    {
        $subject = new Frontpage();

        self::assertSame(
            'text/html',
            $subject->contentType()
        );
    }

    /**
     * @test
     */
    public function returnsContent(): void
    {
        $subject = new Frontpage();

        self::assertStringEqualsFile(
            __DIR__ . '/Assertions/Frontpage.html',
            $subject->content()
        );
    }
}
